Welcome to ClientVPS Mirrors

Help for package h3lib
Type: Package
Title: Exposes the 'Uber' 'H3' Library to R Packages
Version: 0.1.4
Date: 2024-12-12
Description: 'H3' is a hexagonal hierarchical spatial index developed by 'Uber' https://h3geo.org/. This package exposes the source code of 'H3' (written in 'C') to routines that are callable through 'R'.
URL: https://github.com/symbolixau/h3lib
BugReports: https://github.com/symbolixau/h3lib/issues
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.2.3
Suggests: tinytest
Depends: R (≥ 3.0.0)
NeedsCompilation: yes
Packaged: 2024-12-12 00:24:24 UTC; dave
Author: David Cooley [aut, cre], Ray Shao [ctb]
Maintainer: David Cooley <dcooley@symbolix.com.au>
Repository: CRAN
Date/Publication: 2024-12-12 00:40:02 UTC

h3lib

Description

h3lib

Details

h3lib exposes the source code of 'H3' (written in 'C') to routines that are callable through 'R'. Detailed examples on how to call these routines are on the website https://github.com/symbolixau/h3lib#how-do-i-call-these-routines.

Author(s)

Maintainer: David Cooley dcooley@symbolix.com.au

Other contributors:

See Also

Useful links:

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.